//---------------------------------------------
// MetafileViewer.cs  2001 by Charles Petzold
//---------------------------------------------
using System;
using System.Drawing;
using System.Drawing.Imaging;
using System.Drawing.Printing;
using System.IO;              // Para la clase Path 
using System.Windows.Forms;

class MetafileViewer: Form
{
     protected Metafile mf;
     protected string   strProgName;
     protected string   strFileName;
     MenuItem           miFileSaveAs, miFilePrint, 
                        miFileProps, miViewChecked;

     public static void Main()
     {
          Application.Run(new MetafileViewer());
     }
     public MetafileViewer()
     {
          Text = strProgName = "Visor de metarchivos";
          ResizeRedraw = true;

          Menu = new MainMenu();

               // Men Archivo

          MenuItem mi = new MenuItem("&Archivo");
          mi.Popup += new EventHandler(MenuFileOnPopup);
          Menu.MenuItems.Add(mi);

               // Elemento de men Archivo Abrir

          mi = new MenuItem("&Abrir...");
          mi.Click += new EventHandler(MenuFileOpenOnClick);
          mi.Shortcut = Shortcut.CtrlO;
          Menu.MenuItems[0].MenuItems.Add(mi);

               // Elemento de men Archivo Guardar como mapa de bits

          miFileSaveAs = new MenuItem("&Guardar como mapa de bits...");
          miFileSaveAs.Click += new EventHandler(MenuFileSaveAsOnClick);
          Menu.MenuItems[0].MenuItems.Add(miFileSaveAs);
          Menu.MenuItems[0].MenuItems.Add("-");

               // Elemento de men Archivo Imprimir

          miFilePrint = new MenuItem("&Imprimir...");
          miFilePrint.Click += new EventHandler(MenuFilePrintOnClick);
          Menu.MenuItems[0].MenuItems.Add(miFilePrint);
          Menu.MenuItems[0].MenuItems.Add("-");

               // Elemento de men Archivo Propiedades

          miFileProps = new MenuItem("&Propiedades...");
          miFileProps.Click += new EventHandler(MenuFilePropsOnClick);
          Menu.MenuItems[0].MenuItems.Add(miFileProps);

               // Men Edicin (temporal hasta el Captulo 24)

          Menu.MenuItems.Add("&Edicin");

               // Men Ver

          Menu.MenuItems.Add("&Ver");

          string[] astr = { "&Ajustado a la ventana", // $$
                            "Tamao &mtrico", "Tamao en &pxeles" };
          EventHandler eh = new EventHandler(MenuViewOnClick);

          foreach (string str in astr)
               Menu.MenuItems[2].MenuItems.Add(str, eh);

          miViewChecked = Menu.MenuItems[2].MenuItems[0];
          miViewChecked.Checked = true;
     }
     void MenuFileOnPopup(object obj, EventArgs ea)
     {
          miFileSaveAs.Enabled = 
          miFilePrint.Enabled =  
          miFileProps.Enabled = (mf != null);
     }
     void MenuFileOpenOnClick(object obj, EventArgs ea)
     {
          OpenFileDialog dlg = new OpenFileDialog();
	
		  dlg.InitialDirectory = "c:\\";
		  
          dlg.Filter = "Todos los metarchivos|*.wmf;*.emf|" +
                       "Metarchivo de Windows (*.wmf)|*.wmf|" +
                       "Metarchivo mejorado (*.emf)|*.emf|" +
                       "Todos los archivos|*.*";

          if (dlg.ShowDialog() == DialogResult.OK)
          {
               try
               {
                    mf = new Metafile(dlg.FileName);
               }
               catch (Exception exc)
               {
                    MessageBox.Show(exc.Message, strProgName);
                    return;
               }
               strFileName = dlg.FileName;
               Text = strProgName + " - " + Path.GetFileName(strFileName);
               Invalidate();
          }
     }
     protected virtual void MenuFileSaveAsOnClick(object obj, EventArgs ea)
     {
          MessageBox.Show("Sin implementar todava!", strProgName);
     }
     void MenuFilePrintOnClick(object obj, EventArgs ea)
     {
          PrintDocument prndoc = new PrintDocument();

          prndoc.DocumentName = Text;
          prndoc.PrintPage += new PrintPageEventHandler(OnPrintPage);
          prndoc.Print();
     }
     void MenuFilePropsOnClick(object obj, EventArgs ea)
     {
          MetafileHeader mh = mf.GetMetafileHeader();

          string str = 
               "Propiedades de la imagen" +
               "\n\tSize = " + mf.Size + 
               "\n\tHorizontal Resolution = " + mf.HorizontalResolution +
               "\n\tVertical Resolution = " + mf.VerticalResolution +
               "\n\tPhysical Dimension = " + mf.PhysicalDimension +
               "\n\nPropiedades de la cabecera del metarchivo" +
               "\n\tBounds = " + mh.Bounds +
               "\n\tDpiX = " + mh.DpiX +
               "\n\tDpiY = " + mh.DpiY +
               "\n\tLogicalDpiX = " + mh.LogicalDpiX +
               "\n\tLogicalDpiY = " + mh.LogicalDpiY +
               "\n\tType = " + mh.Type +
               "\n\tVersion = " + mh.Version +
               "\n\tMetafileSize = " + mh.MetafileSize;

          MessageBox.Show(str, Text);
     }
     void MenuViewOnClick(object obj, EventArgs ea)
     {
          miViewChecked.Checked = false;
          miViewChecked = (MenuItem) obj;
          miViewChecked.Checked = true;
          Invalidate();
     }
     void OnPrintPage(object obj, PrintPageEventArgs ppea)
     {
          Graphics  grfx = ppea.Graphics;
          Rectangle rect = new Rectangle(
               ppea.MarginBounds.Left -
               (ppea.PageBounds.Width - 
                    (int) grfx.VisibleClipBounds.Width) / 2,
               ppea.MarginBounds.Top -
               (ppea.PageBounds.Height - 
                    (int) grfx.VisibleClipBounds.Height) / 2,
               ppea.MarginBounds.Width,
               ppea.MarginBounds.Height);

          DisplayMetafile(grfx, rect);
     }
     protected override void OnPaint(PaintEventArgs pea)
     {
          if (mf != null)
               DisplayMetafile(pea.Graphics, ClientRectangle);
     }
     void DisplayMetafile(Graphics grfx, Rectangle rect)
     {
          switch (miViewChecked.Index)
          {
          case 0: grfx.DrawImage(mf, rect);  break;
          case 1: grfx.DrawImage(mf, rect.X, rect.Y);  break;
          case 2: grfx.DrawImage(mf, rect.X, rect.Y, mf.Width, mf.Height);
                  break;
          }
     }
}